<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
  
}

/**
 * Service Widget
 */

class Service_Widget extends \Elementor\Widget_Base {
  public function get_name() {
    return "opticore-service";
  }

  public function get_title() {
    return "opticore Service";
  }

  public function get_categories() {
    return ['basic'];
  }


  protected function register_controls() {

    $this->start_controls_section(
      'content_section',
      [
        'label' => esc_html__('Service Content', 'plugin-name'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

    // Service Style
    $this->add_control(
      'service_style',
      [
        'label' => esc_html__('Service Style', 'textdomain'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => '1',
        'options' => [
          '1'  => esc_html__('One', 'textdomain'),
          '2' => esc_html__('Two', 'textdomain'),
          '3' => esc_html__('Three', 'textdomain'),
          '4' => esc_html__('Four', 'textdomain'),
          '5' => esc_html__('Five', 'textdomain'),
          '6' => esc_html__('Six', 'textdomain'),
        ],
      ]
    );
	


		$this->add_responsive_control(
			'align',
			[
				'label' => esc_html__( 'Alignment', 'elementor' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'elementor' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'elementor' ),
						'icon' => 'eicon-text-align-justify',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .ab_ser_ar, {{WRAPPER}} .service_03 .tb_serice_ar, {{WRAPPER}} .service_04 .tb_serice' => 'text-align: {{VALUE}};',
				],
			]
		);
	
    // Title
    $this->add_control(
      'list_title',
      [
        'label' => esc_html__('Title', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::TEXTAREA,
        'default' => esc_html__('Service Title', 'plugin-name'),
        'label_block' => true,
      ]
    );
    // Url
    $this->add_control(
      'service_link',
      [
        'label' => esc_html__('Link', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::URL,
        'placeholder' => esc_html__('https://your-link.com', 'plugin-name'),
        'options' => ['url', 'is_external', 'nofollow'],
        'default' => [
          'url' => '#',
          'is_external' => true,
          'nofollow' => true,
          // 'custom_attributes' => '',
        ],
        'label_block' => true,
      ]
    );
	
	   // Description
    $this->add_control(
      'desc',
      [
        'label' => 'Description',
        'type' => \Elementor\Controls_Manager::TEXTAREA,
        'default' => ("If you are going to use a passage.."),
		'placeholder' => esc_attr__( 'your content'),
      ]
	  
    );

	 $this->add_control(
	'descs',
      [
        'label' => 'text',
        'type' => \Elementor\Controls_Manager::TEXTAREA,
        'default' => ("125 min"),
		'placeholder' => esc_attr__( 'your content'),
      ]
	  
    );
	
	
	// Show Icon
    $this->add_control(
			'show_icon',
			[
				'label' => esc_html__( 'Show Icon', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'your-plugin' ),
				'label_off' => esc_html__( 'Hide', 'your-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
	

    // Icon
    $this->add_control(
      'service_icon',
      [
        'label' => esc_html__('Icon', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::ICONS,
        'default' => [
          'value' => 'fas fa-circle',
          'library' => 'fa-solid',
        ],
        'recommended' => [
          'fa-solid' => [
            'circle',
            'dot-circle',
            'square-full',
          ],
          'fa-regular' => [
            'circle',
            'dot-circle',
            'square-full',
          ],
        ],
		'condition' => [
				'show_icon' => 'yes',
			],
      ]
    );

	// Show Image
    $this->add_control(
			'show_img',
			[
				'label' => esc_html__( 'Show Image', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'your-plugin' ),
				'label_off' => esc_html__( 'Hide', 'your-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
	
    // Image
    $this->add_control(
      'service_image',
      [
        'label' => esc_html__('Choose Image', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::MEDIA,
        'default' => [
          'url' => plugin_dir_url(__DIR__) . 'assets/images/placeholder.png',
        ],
		'condition' => [
				'show_img' => 'yes',
			],
      ]
    );
	
	// Show Image
    $this->add_control(
			'show_btn',
			[
				'label' => esc_html__( 'Show Button', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'your-plugin' ),
				'label_off' => esc_html__( 'Hide', 'your-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
    // Button Text
    $this->add_control(
      'btn_txt',
      [
        'label' => esc_html__('Button Text', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::TEXTAREA,
        'default' => esc_html__('Read More', 'plugin-name'),
        'label_block' => true,
        'condition' => [
				'show_btn' => 'yes',
			],
      ]
    );
	// Button Text
    $this->add_control(
      'btns_txt',
      [
        'label' => esc_html__('Text', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::TEXTAREA,
        'default' => esc_html__('ENGLISH', 'plugin-name'),
        'label_block' => true,
        'condition' => [
          'service_style' =>['5']
        ],
      ]
    );

    $this->end_controls_section();


    /**
     *Style 02 Part
     */

	 // Box Style
	 $this->start_controls_section(
      'box_style',
      [
        'label' => 'Box Color Option',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );
	// Box Background  
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'arrows_hover_background',
        'label' => esc_html__('Background', 'plugin-name'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .tb_service,{{WRAPPER}} .tb_service_sen, {{WRAPPER}} .tb_serice_ar ',
      ]
    ); 
	  // Box Padding 
    $this->add_responsive_control(
      'ser_box_padding',
      [
        'label' => 'Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .tb_service ,{{WRAPPER}} .tb_service_sen, {{WRAPPER}} .tb_serice_ar ' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    // Box Margin
    $this->add_responsive_control(
      'ser_box_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .tb_service, {{WRAPPER}} .tb_service_sen, {{WRAPPER}} .tb_serice_ar' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );
	 
	/* box shadow */	
	$this->add_group_control(
		\Elementor\Group_Control_Box_Shadow::get_type(),
		[
			'name' => 'witr_box_shadowsbox',
			'label' => esc_html__( 'Box Shadow', 'opticore' ),
			'selector' => '{{WRAPPER}} .tb_service, {{WRAPPER}} .tb_service_sen, {{WRAPPER}} .tb_serice_ar, {{WRAPPER}} .tb_serice',
		]
	); 
	 
	 /* witr_border_style */
	$this->add_control(
		'box_border',
		[
			'label' => esc_html__( 'Border Style', 'plugin-name' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'none' => esc_html__( 'none', 'plugin-name' ),
				'solid' => esc_html__( 'Solid', 'plugin-name' ),
				'double' => esc_html__( 'Double', 'plugin-name' ),
				'dotted' => esc_html__( 'Dotted', 'plugin-name' ),
				'dashed' => esc_html__( 'Dashed', 'plugin-name' ),
				'default' => esc_html__( 'Default', 'plugin-name' ),
			],
			'default' => 'none',
			'selectors' => [
				 '{{WRAPPER}} .tb_service, {{WRAPPER}} .tb_service_sen, {{WRAPPER}} .tb_serice_ar' => 'border-style: {{VALUE}}',
			],
		]
	);		
	/* witr border */
	
	$this->add_control(
		'box_bods_style',
		[
			'label' => esc_html__( 'Width', 'plugin-name' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'selectors' => [
				 '{{WRAPPER}} .tb_service, {{WRAPPER}} .tb_service_sen, {{WRAPPER}} .tb_serice_ar' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
			'condition' => [
				'box_border' => ['solid','double','dotted','dashed'],
			],								
		]
	);
	/* border_color */
	$this->add_control(
		'boxs_border1_color',
		[
			'label' => esc_html__( 'Border Color', 'plugin-name' ),
			'type' =>  \Elementor\Controls_Manager::COLOR,
			
			'selectors' => [
				'{{WRAPPER}} .tb_service, {{WRAPPER}} .tb_service_sen, {{WRAPPER}} .tb_serice_ar' => 'border-color: {{VALUE}}',
			],
			'condition' => [
				'box_border' => ['solid','double','dotted','dashed','default'],
			],								
		]
	);
	/* border_radius */
	$this->add_control(
		'service_border_radius',
		[
			'label' => esc_html__( 'Border Radius', 'plugin-name' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors' => [
				'{{WRAPPER}} .tb_service, {{WRAPPER}} .tb_service_sen, {{WRAPPER}} .tb_serice_ar' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],							
		]
	);
	 
	 
	 /* border_color */
	$this->add_control(
		'border1_hover_color',
		[
			'label' => esc_html__( 'Border Hover Color', 'plugin-name' ),
			'type' =>  \Elementor\Controls_Manager::COLOR,
			
			'selectors' => [
				'{{WRAPPER}} .tb_service:hover, {{WRAPPER}} .tb_service_sen:hover' => 'border-color: {{VALUE}}',
			],
		]
	);
	
	
	
	// Box Background  
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'Box_hover_background',
        'label' => esc_html__('Background', 'plugin-name'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .tb_service,{{WRAPPER}} .tb_service_sen, {{WRAPPER}} .tb_serice_ar:hover  ',
      ]
    ); 
	
	
	
	
	
	
	$this->end_controls_section();
	 
	// Box Content
	 $this->start_controls_section(
      'box_conten_style',
      [
        'label' => 'Box Content',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );
	
	// Box Background  
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'con_background',
        'label' => esc_html__('Background', 'plugin-name'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .service_text_item, {{WRAPPER}} .tb_serice, {{WRAPPER}} .text_item_ar, {{WRAPPER}} .service_03 .tb_serice_ar',
      ]
    );
	  // Box Padding 
    $this->add_responsive_control(
      'ser_boxs_padding',
      [
        'label' => 'Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .service_text_item, {{WRAPPER}} .tb_serice , {{WRAPPER}} .text_item_ar, {{WRAPPER}} .sitem_content, {{WRAPPER}} .service_03 .tb_serice_ar' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );
	// Box Margin
    $this->add_responsive_control(
      'conten_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .tb_serice_content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );
	/* border_radius */
	$this->add_control(
		'box_bd_radius',
		[
			'label' => esc_html__( 'Border Radius', 'plugin-name' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors' => [
				'{{WRAPPER}} .service_text_item, {{WRAPPER}} .tb_serice , {{WRAPPER}} .text_item_ar, {{WRAPPER}} .service_03 .tb_serice_ar' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],							
		]
	);
	
	/* hedding  */
	$this->add_control(
		'witr_hov',
		[
			'label' => esc_html__( ' Hover option', 'opticore' ),
			'type' => \Elementor\Controls_Manager::HEADING,
		]
	);
	// Box Background  
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'hove_background',
        'label' => esc_html__('Background', 'plugin-name'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .tb_service_sen:hover .tb_serice ,{{WRAPPER}} .text_item_ar, {{WRAPPER}} .service_03 .tb_serice_ar:hover',
      ]
    );
	 
	 $this->end_controls_section();
	 
	 
	 
	 
		 
	 
	
	   /**
     * Icon Style
     */

	 
	$this->start_controls_section(
      'icon_style',
      [
        'label' => 'Icon Option',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );
	
    // Icon Color
    $this->add_control(
      'icon_color',
      [
        'label' => 'Color',
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .ab_ser_ar i, {{WRAPPER}} .icon_ar i' => 'color: {{VALUE}}',
        ]
      ]
    );

	// Box Background  
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'icon_background',
        'label' => esc_html__('Background', 'plugin-name'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .service_icon',
      ]
    );
	
    // Icon Size
    $this->add_responsive_control(
      'icon_size',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('Size', 'plugin-name'),
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 200,
          ],
        ],
        'devices' => ['desktop', 'tablet', 'mobile'],
        'selectors' => [
          '{{WRAPPER}} .service_icon' => 'font-size: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
	
	$this->add_responsive_control(
			'align',
			[
				'label' => esc_html__( 'Alignment', 'elementor' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'elementor' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'elementor' ),
						'icon' => 'eicon-text-align-justify',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .service_icon, {{WRAPPER}} .icon_ar i,{{WRAPPER}} .ab_ser_ar i ' => 'text-align: {{VALUE}};',
				],
			]
		);
	
	// Arrow Width
    $this->add_responsive_control(
      'ser_icons_width',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('Width', 'plugin-name'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
          '{{WRAPPER}} .service_text_item i, {{WRAPPER}} .icon_ar i,{{WRAPPER}} .ab_ser_ar i ' => 'width: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
	// Arrow height
    $this->add_responsive_control(
      'ser_icons_height',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('height', 'plugin-name'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
           '{{WRAPPER}} .service_text_item i, {{WRAPPER}} .icon_ar i,{{WRAPPER}} .ab_ser_ar i ' => 'height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );	
	// Line height
    $this->add_responsive_control(
      'ser_icons_line_height',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('line-height', 'plugin-name'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
           '{{WRAPPER}} .service_text_item i, {{WRAPPER}} .icon_ar i,{{WRAPPER}} .ab_ser_ar i ' => 'line-height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
	/* witr_border_style */
	$this->add_control(
		'icons_border',
		[
			'label' => esc_html__( 'Border Style', 'plugin-name' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'none' => esc_html__( 'none', 'plugin-name' ),
				'solid' => esc_html__( 'Solid', 'plugin-name' ),
				'double' => esc_html__( 'Double', 'plugin-name' ),
				'dotted' => esc_html__( 'Dotted', 'plugin-name' ),
				'dashed' => esc_html__( 'Dashed', 'plugin-name' ),
				'default' => esc_html__( 'Default', 'plugin-name' ),
			],
			'default' => 'none',
			'selectors' => [
				 '{{WRAPPER}} .service_text_item i, {{WRAPPER}} .icon_ar i,{{WRAPPER}} .ab_ser_ar i' => 'border-style: {{VALUE}}',
			],
		]
	);		
	/* witr border */
	
	$this->add_control(
		'icon_bods_style',
		[
			'label' => esc_html__( 'Width', 'plugin-name' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'selectors' => [
				 '{{WRAPPER}} .service_text_item i, {{WRAPPER}} .icon_ar i,{{WRAPPER}} .ab_ser_ar i' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
			'condition' => [
				'icons_border' => ['solid','double','dotted','dashed'],
			],								
		]
	);
	/* border_color */
	$this->add_control(
		'ser_border1_color',
		[
			'label' => esc_html__( 'Border Color', 'plugin-name' ),
			'type' =>  \Elementor\Controls_Manager::COLOR,
			
			'selectors' => [
				'{{WRAPPER}} .service_text_item i, {{WRAPPER}} .icon_ar i,{{WRAPPER}} .ab_ser_ar i' => 'border-color: {{VALUE}}',
			],
			'condition' => [
				'icons_border' => ['solid','double','dotted','dashed','default'],
			],								
		]
	);
	/* border_radius */
	$this->add_control(
		'icons_radius',
		[
			'label' => esc_html__( 'Border Radius', 'plugin-name' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors' => [
				'{{WRAPPER}} .service_text_item i, {{WRAPPER}} .icon_ar i, {{WRAPPER}} .ab_ser_ar i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],							
		]
	);
	
	
	
	 // icons Padding
    $this->add_responsive_control(
      'icons_padding',
      [
        'label' => 'Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .service_icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    // icons Margin
    $this->add_responsive_control(
      'icons_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .service_icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );
	
	$this->add_responsive_control(
			'icon_position',
			[
				'label' => esc_html__( 'Position', 'opticore' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => esc_html__( 'Default', 'opticore' ),
					'absolute' => esc_html__( 'Absolute', 'opticore' ),
					'fixed' => esc_html__( 'Fixed', 'opticore' ),
					'inherit' => esc_html__( 'inherit', 'opticore' ),
				],
				'selectors' => [
							'{{WRAPPER}} .ab_ser_ar i' => 'position: {{VALUE}};',
						],
			]
		);
		
		/* witr_icon_top */
				$this->add_responsive_control(
					'witr_icon_top',
					[
						'label' => esc_html__( 'Icon Top', 'opticore' ),
						'type' => \Elementor\Controls_Manager::SLIDER,
						'size_units' => [ 'px', '%' ],
						'range' => [
							'px' => [
								'min' => -100,
								'max' => 500,
							],
							'%' => [
								'min' => -100,
								'max' => 100,
							],		
						],
						'condition' => [
							'icon_position' => ["absolute","fixed"],
						],						
						'selectors' => [
							'{{WRAPPER}} .ab_ser_ar i' => 'top: {{SIZE}}{{UNIT}};',
						],
					]
				);
				
				/* witr_icon_left */
				$this->add_responsive_control(
					'witr_icon_left',
					[
						'label' => esc_html__( 'Icon Left', 'opticore' ),
						'type' => \Elementor\Controls_Manager::SLIDER,
						'size_units' => [ 'px', '%' ],
						'range' => [
							'px' => [
								'min' => -100,
								'max' => 500,
							],
							'%' => [
								'min' => -100,
								'max' => 100,
							],	
						],
						'condition' => [
							'icon_position' => ["absolute","fixed"],
						],						
						'selectors' => [
							'{{WRAPPER}} .ab_ser_ar i' => 'left: {{SIZE}}{{UNIT}};',
						],
					]
				);				
				
	
/* hedding  */
	$this->add_control(
		'witr_hove',
		[
			'label' => esc_html__( ' Hover Color option', 'opticore' ),
			'type' =>\Elementor\Controls_Manager::HEADING,
		]
	);
    
    // icon1 Color
    $this->add_control(
      'icon1_hover_color',
      [
        'label' => 'Color',
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .tb_service_sen:hover .icon_ar i' => 'color: {{VALUE}}',
        ]
      ]
    );

    // icon1 Background
    $this->add_control(
      'icon1_hover_bg',
      [
        'label' => 'Background',
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .tb_service_sen:hover .icon_ar i' => 'background-color: {{VALUE}}',
        ]
      ]
    );

   
	
	
    $this->end_controls_section();


    /**
     * Title Style
     */

    $this->start_controls_section(
      'title_style',
      [
        'label' => 'Title Option',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Title Color 
    $this->add_control(
      'title_color',
      [
        'label' => 'Color',
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .service_title , {{WRAPPER}} .text_item_ar h3 , {{WRAPPER}} .text_item_ar h3 a, {{WRAPPER}} .sitem_content h3 a' => 'color: {{VALUE}}',
        ] 
      ]
    );

    // Title Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'title_typography',
        'selector' => '{{WRAPPER}} .service_title, {{WRAPPER}} .text_item_ar h3 a, {{WRAPPER}} .sitem_content h3 a ',
      ]
    );
	// Title margin
	  $this->add_responsive_control(
		'title_margin',
		[
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'label' => esc_html__( 'Margin', 'textdomain' ),
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'{{WRAPPER}} .service_title , {{WRAPPER}} .text_item_ar h3,{{WRAPPER}} .tb_serice_content h3,{{WRAPPER}} .sitem_content h3,{{WRAPPER}} .tb_service_sen h1 ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);


    $this->end_controls_section();
	
	

 $this->start_controls_section(
      'number_style',
      [
        'label' => 'Number Option',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Title Color 
    $this->add_control(
      'number_color',
      [
        'label' => 'Color',
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .time_all span' => 'color: {{VALUE}}',
        ]
      ]
    );

    // Title Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'number_typography',
        'selector' => '{{WRAPPER}} .time_all span',
      ]
    );
	// Title margin
	  $this->add_responsive_control(
		'number_margin',
		[
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'label' => esc_html__( 'Margin', 'textdomain' ),
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'{{WRAPPER}} .time_all' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);


    $this->end_controls_section();
	
 /**
     * Content Style
     */

    $this->start_controls_section(
      'content_style',
      [
        'label' => 'Content Option',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Title Color 
    $this->add_control(
      'content_color',
      [
        'label' => 'Color',
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .sitem_content p , {{WRAPPER}} .text_item_ar p, {{WRAPPER}} .tb_serice_content p, {{WRAPPER}} .ab_ser_ar p ' => 'color: {{VALUE}}',
        ]
      ]
    );

    // Title Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'content_typography',
        'selector' => '{{WRAPPER}} .sitem_content p , {{WRAPPER}} .text_item_ar p, {{WRAPPER}} .ab_ser_ar p, {{WRAPPER}} .tb_serice_content p',
      ]
    );

	$this->add_responsive_control(
		'content_margin',
		[
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'label' => esc_html__( 'Margin', 'textdomain' ),
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'{{WRAPPER}} .sitem_content p , {{WRAPPER}} .text_item_ar p, {{WRAPPER}} .ab_ser_ar p, {{WRAPPER}} .tb_serice_content p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);

    $this->end_controls_section();	
	
	
	
	
	
	
    /**
     * Image Style
     */

    $this->start_controls_section(
      'image_style',
      [
        'label' => 'Image Option',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Image Overlay
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'image_overlay_background',
        'label' => esc_html__('Overlay Background', 'textdomain'),
        'types' => ['classic', 'gradient', 'video'],
        'selector' => '{{WRAPPER}} .service_image:before',
      ]
    );
	


    $this->end_controls_section();
	
	
	  /**
     * Title Style
     */

    $this->start_controls_section(
      'all_style',
      [
        'label' => 'All Hover color Option',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );
    // Title Color
    $this->add_control(
      'all_ho_color',
      [
        'label' => 'Color',
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .tb_service_sen:hover .tb_serice h3 a, {{WRAPPER}} .tb_service_sen:hover .tb_serice p' => 'color: {{VALUE}}',
        ]
      ]
    );



    $this->end_controls_section();


	
	
	

    /**
     * Arrow Style
     */

    $this->start_controls_section(
      'arrow_style',
      [
        'label' => 'Arrow Option',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
        'condition' => [
          'service_style' => '1'
        ]
      ]
    );

    $this->start_controls_tabs(
      'style_tabs'
    );

    // Normal Tab
    $this->start_controls_tab(
      'style_normal_tab',
      [
        'label' => esc_html__('Normal', 'textdomain'),
      ]
    );

    // Arrow Color
    $this->add_control(
      'ser_icon_color',
      [
        'label' => 'Color',
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .ser_icon i' => 'color: {{VALUE}}',
        ]
      ]
    );

    // Arrow Background
    $this->add_control(
      'icon_bg',
      [
        'label' => 'Background',
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .ser_icon i' => 'background-color: {{VALUE}}',
        ]
      ]
    );
	
	// Arrow Width
    $this->add_responsive_control(
      'ser_icon_width',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('Width', 'plugin-name'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
          '{{WRAPPER}} .ser_icon i' => 'width: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
	// Arrow height
    $this->add_responsive_control(
      'ser_icon_height',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('height', 'plugin-name'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
          '{{WRAPPER}} .ser_icon i' => 'height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );	
	// Line height
    $this->add_responsive_control(
      'ser_icon_line-height',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('line-height', 'plugin-name'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
          '{{WRAPPER}} .ser_icon i' => 'line-height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
	/* witr_border_style */
	$this->add_control(
		'arrow_border',
		[
			'label' => esc_html__( 'Border Style', 'plugin-name' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'none' => esc_html__( 'none', 'plugin-name' ),
				'solid' => esc_html__( 'Solid', 'plugin-name' ),
				'double' => esc_html__( 'Double', 'plugin-name' ),
				'dotted' => esc_html__( 'Dotted', 'plugin-name' ),
				'dashed' => esc_html__( 'Dashed', 'plugin-name' ),
				'default' => esc_html__( 'Default', 'plugin-name' ),
			],
			'default' => 'none',
			'selectors' => [
				'{{WRAPPER}} .ser_icon i' => 'border-style: {{VALUE}}',
			],
		]
	);		
	/* witr border */
	
	$this->add_control(
		'arrow_btn_style',
		[
			'label' => esc_html__( 'Width', 'plugin-name' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'selectors' => [
				'{{WRAPPER}} .ser_icon i' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
			'condition' => [
				'arrow_border' => ['solid','double','dotted','dashed'],
			],								
		]
	);
	/* border_color */
	$this->add_control(
		'witr_border1_btn_color',
		[
			'label' => esc_html__( 'Border Color', 'plugin-name' ),
			'type' =>  \Elementor\Controls_Manager::COLOR,
			
			'selectors' => [
				'{{WRAPPER}} .ser_icon i' => 'border-color: {{VALUE}}',
			],
			'condition' => [
				'arrow_border' => ['solid','double','dotted','dashed','default'],
			],								
		]
	);
	/* border_radius */
	$this->add_control(
		'arrow_radius',
		[
			'label' => esc_html__( 'Border Radius', 'plugin-name' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors' => [
				'{{WRAPPER}} .ser_icon i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
			'condition' => [
				'arrow_border' => ['solid','double','dotted','dashed','default'],
			],								
		]
	);

	/* witr_icon_top */
	$this->add_responsive_control(
		'arrow_top',
		[
			'label' => esc_html__( 'Arrow Top', 'opticore' ),
			'type' => \Elementor\Controls_Manager::SLIDER,
			'size_units' => [ 'px', '%' ],
			'range' => [
				'px' => [
					'min' => -100,
					'max' => 500,
				],
				'%' => [
					'min' => -100,
					'max' => 100,
				],		
			],						
			'selectors' => [
				'{{WRAPPER}} .ser_icon i' => 'top: {{SIZE}}{{UNIT}};',
			],
		]
	);
	// Left
	$this->add_responsive_control(
		'arrow_Left',
		[
			'label' => esc_html__( 'Arrow Left', 'opticore' ),
			'type' => \Elementor\Controls_Manager::SLIDER,
			'size_units' => [ 'px', '%' ],
			'range' => [
				'px' => [
					'min' => -100,
					'max' => 500,
				],
				'%' => [
					'min' => -100,
					'max' => 100,
				],		
			],						
			'selectors' => [
				'{{WRAPPER}} .ser_icon i' => 'left: {{SIZE}}{{UNIT}};',
			],
		]
	);
	// right
	$this->add_responsive_control(
		'arrow_right',
		[
			'label' => esc_html__( 'Arrow right', 'opticore' ),
			'type' => \Elementor\Controls_Manager::SLIDER,
			'size_units' => [ 'px', '%' ],
			'range' => [
				'px' => [
					'min' => -100,
					'max' => 500,
				],
				'%' => [
					'min' => -100,
					'max' => 100,
				],		
			],						
			'selectors' => [
				'{{WRAPPER}} .ser_icon i' => 'right: {{SIZE}}{{UNIT}};',
			],
		]
	);

	

    $this->end_controls_tab();

    // Hover Tab
    $this->start_controls_tab(
      'style_hover_tab',
      [
        'label' => esc_html__('Hover', 'textdomain'),
      ]
    );

    // Arrow Color
    $this->add_control(
      'arrow_hover_color',
      [
        'label' => 'Color',
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .ser_icon i:hover' => 'color: {{VALUE}}',
        ]
      ]
    );

    // Arrow Background
    $this->add_control(
      'arrow_hover_bg',
      [
        'label' => 'Background',
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .ser_icon i:hover' => 'background-color: {{VALUE}}',
        ]
      ]
    );

    $this->end_controls_tab();

    $this->end_controls_tabs();

    $this->end_controls_section();


    /** Button Style */

    $this->start_controls_section(
      'button_style',
      [
        'label' => 'Button',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
        
      ]
    );

    // Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'button_typography',
        'selector' => '{{WRAPPER}} .tabtn',
      ]
    );

    $this->start_controls_tabs(
      'btn_style_tabs'
    );

    // Normal Tab
    $this->start_controls_tab(
      'btn_style_normal_tab',
      [
        'label' => esc_html__('Normal', 'plugin-name'),
      ]
    );

    // Color
    $this->add_control(
      'btn_title_color',
      [
        'label' => esc_html__('Title Color', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .tabtn' => 'color: {{VALUE}}',
        ],
      ]
    );


    // Background
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'btn_background',
        'label' => esc_html__('Background', 'plugin-name'),
        'types' => ['classic', 'gradient', 'video'],
        'selector' => '{{WRAPPER}} .tabtn',
      ]
    );
	
	
	 /* witr_border_style */
	$this->add_control(
		'btn_border',
		[
			'label' => esc_html__( 'Border Style', 'plugin-name' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'none' => esc_html__( 'none', 'plugin-name' ),
				'solid' => esc_html__( 'Solid', 'plugin-name' ),
				'double' => esc_html__( 'Double', 'plugin-name' ),
				'dotted' => esc_html__( 'Dotted', 'plugin-name' ),
				'dashed' => esc_html__( 'Dashed', 'plugin-name' ),
				'default' => esc_html__( 'Default', 'plugin-name' ),
			],
			'default' => 'none',
			'selectors' => [
				 '{{WRAPPER}} .tabtn' => 'border-style: {{VALUE}}',
			],
		]
	);		
	/* witr border */
	
	$this->add_control(
		'btn_bods_style',
		[
			'label' => esc_html__( 'Width', 'plugin-name' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'selectors' => [
				 '{{WRAPPER}} .tabtn' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
			'condition' => [
				'btn_border' => ['solid','double','dotted','dashed'],
			],								
		]
	);
	/* border_color */
	$this->add_control(
		'btn_border1_color',
		[
			'label' => esc_html__( 'Border Color', 'plugin-name' ),
			'type' =>  \Elementor\Controls_Manager::COLOR,
			
			'selectors' => [
				'{{WRAPPER}} .tabtn' => 'border-color: {{VALUE}}',
			],
			'condition' => [
				'btn_border' => ['solid','double','dotted','dashed','default'],
			],								
		]
	);
	/* border_radius */
	$this->add_control(
		'btn_radius',
		[
			'label' => esc_html__( 'Border Radius', 'plugin-name' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors' => [
				'{{WRAPPER}} .tabtn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],							
		]
	);
	
	
	
	

    $this->end_controls_tab();

    // Hover Tab
    $this->start_controls_tab(
      'btn_style_hover_tab',
      [
        'label' => esc_html__('Hover', 'plugin-name'),
      ]
    );

    // Color
    $this->add_control(
      'btn_hover_title_color',
      [
        'label' => esc_html__('Title Color', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .tabtn:hover' => 'color: {{VALUE}}',
        ],
      ]
    );


    // Background
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'btn_hover_background',
        'label' => esc_html__('Background', 'plugin-name'),
        'types' => ['classic', 'gradient', 'video'],
        'selector' => '{{WRAPPER}} .tabtn:hover',
      ]
    );


    $this->end_controls_tab();

    $this->end_controls_tabs();


    // Padding
    $this->add_responsive_control(
      'button_padding',
      [
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'label' => esc_html__( 'Padding', 'plugin-name' ),
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .tabtn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

    $this->end_controls_section();

  }


  protected function render() {
    $settings = $this->get_settings_for_display();
?>

    <?php
    if (!empty($settings['service_link']['url'])) {
      $this->add_link_attributes('service_link', $settings['service_link']);
    }

    ?>
    <!--========  service ======== -->

    <?php if ($settings['service_style'] === '1') : ?>
      <div class="tb_service_sen">
        <div class="tb_service">
          <div class="service_text_item">
		  <?php if('yes' === $settings['show_icon']): ?>
            <?php \Elementor\Icons_Manager::render_icon($settings['service_icon'], ['aria-hidden' => 'true', 'class' => 'service_icon']); ?>
			<?php endif ?>
            <h3><a class="service_title" <?php echo $this->get_render_attribute_string('service_link'); ?>><?= $settings['list_title'] ?></a></h3>
			<p> <?= $settings['desc'] ?></p>
          </div>
          <div class="service_image">
            <div class="service_image">
              <img src="<?= esc_url($settings['service_image']['url']) ?>" alt="">
            </div>
            <div class="ser_icon">
              <i class="icofont-arrow-right"></i>
            </div>
          </div>
        </div>
      </div>
	  
	  <?php elseif ($settings['service_style'] === '2') : ?>
	  <div class="tb_service_sen ab_ser_ar">
	  <?php if('yes' === $settings['show_icon']): ?>
	  <?php \Elementor\Icons_Manager::render_icon($settings['service_icon'], ['aria-hidden' => 'true', 'class' => 'service_icon']); ?>
	   <?php endif ?>
	   <div class="ab_ser_img">
	   <?php if('yes' === $settings['show_img']): ?>
		   <img src="<?= esc_url($settings['service_image']['url']) ?>" alt="">
		   <?php endif ?>
	   </div>
	   <h1><a class="service_title" <?php echo $this->get_render_attribute_string('service_link'); ?>><?= $settings['list_title'] ?></a></h1>
	   <p> <?= $settings['desc'] ?></p>
	    <?php if('yes' === $settings['show_btn']): ?>
			<a <?php echo $this->get_render_attribute_string('service_link'); ?> class="tabtn"><?= $settings['btn_txt'] ?></a>
		<?php endif ?>
	</div>

	<?php elseif ($settings['service_style'] === '3') : ?>
      <div class="tb_service_sen service_02">
        <div class="tb_serice">
          <div class="icon_ar">
          <?php \Elementor\Icons_Manager::render_icon($settings['service_icon'], ['aria-hidden' => 'true', 'class' => 'service_icon']); ?>
          </div>
		  <div class="tb_serice_con">
			  <h3><a class="service_title" <?php echo $this->get_render_attribute_string('service_link'); ?>><?= $settings['list_title'] ?></a></h3>
			  <p> <?= $settings['desc'] ?></p>
		  </div>
        </div>
        <div class="service_image">
          <img src="<?= esc_url($settings['service_image']['url']) ?>" alt="">
          <div class="sitem_btn">
            <?php if('yes' === $settings['show_btn']): ?>
				<a <?php echo $this->get_render_attribute_string('service_link'); ?> class="tabtn"><?= $settings['btn_txt'] ?></a>
			<?php endif ?>
          </div>
        </div>
      </div>
	  
	 <?php elseif ($settings['service_style'] === '4') : ?>
      <div class="tb_service_sen service_04">
        <div class="tb_serice">
          <div class="icon_ar">
          <?php \Elementor\Icons_Manager::render_icon($settings['service_icon'], ['aria-hidden' => 'true', 'class' => 'service_icon']); ?>
		  
          </div>
		  <div class="ab_ser_img">
	   <?php if('yes' === $settings['show_img']): ?>
		   <img src="<?= esc_url($settings['service_image']['url']) ?>" alt="">
		   <?php endif ?>
	   </div>
		  <div class="tb_serice_content">
			  <h3><a class="service_title" <?php echo $this->get_render_attribute_string('service_link'); ?>><?= $settings['list_title'] ?></a></h3>
			  <p> <?= $settings['desc'] ?></p>
			  <?php if('yes' === $settings['show_btn']): ?>
			  <a <?php echo $this->get_render_attribute_string('service_link'); ?> class="tabtn"><?= $settings['btn_txt'] ?></a>
			  <?php endif ?>
			</div>
        </div>
      </div>
	  
	  <?php elseif ($settings['service_style'] === '5') : ?>
		<div class="tb_service_sen service_03 service_05">
			<div class="service_image">
				<img src="<?= esc_url($settings['service_image']['url']) ?>" alt="">
			</div>
			 <div class="tb_serice_ar">
				<div class="icon_ar">
				  <?php \Elementor\Icons_Manager::render_icon($settings['service_icon'], ['aria-hidden' => 'true', 'class' => 'service_icon']); ?>
				</div>
				<div class="sitem_content">
				<h3><a <?php echo $this->get_render_attribute_string('service_link'); ?>><?= $settings['list_title'] ?></a></h3>
				   <p> <?= $settings['desc'] ?></p>
				   <div class="btn_area">
				   <?php if('yes' === $settings['show_btn']): ?>
						<a <?php echo $this->get_render_attribute_string('service_link'); ?> class="tabtn"><?= $settings['btn_txt'] ?></a>
					<?php endif ?>
				   </div>
				</div>
			 </div>
		</div>
		
		<?php elseif ($settings['service_style'] === '6') : ?>
			<div class="tb_service_sen service_03 service_05">
			<div class="service_image">
				<img src="<?= esc_url($settings['service_image']['url']) ?>" alt="">
			</div>
			 <div class="tb_serice_ar">
				<div class="icon_ar">
				  <?php \Elementor\Icons_Manager::render_icon($settings['service_icon'], ['aria-hidden' => 'true', 'class' => 'service_icon']); ?>
				</div>
				<div class="sitem_content">
				<div class="time_all">
					<span><?= $settings['descs'] ?></span>
				</div>
				<h3><a <?php echo $this->get_render_attribute_string('service_link'); ?>><?= $settings['list_title'] ?></a></h3>
				   <p> <?= $settings['desc'] ?></p>
				</div>
			 </div>
		</div>
		
    <?php endif ?>
<?php
  }
}
