<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}

/**
 * Images Widget
 */

class Image_Widget extends \Elementor\Widget_Base


{
  public function get_name()
  {
    return 'opticore-image';
  }

  public function get_title()
  {
    return esc_html__('opticore Image', 'opticore-widget');
  }

  public function get_categories()
  {
    return ['basic'];
  }


  protected function register_controls()
  {
    /**
     * Image Control Section
     */
	
    $this->start_controls_section(
      'content_section',
      [
        'label' => 'Content',
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

	 $this->add_responsive_control(
			'img_aligg',
			[
				'label' => esc_html__( 'Alignment', 'elementor' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'elementor' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'elementor' ),
						'icon' => 'eicon-text-align-justify',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .t1_about_thumb img, {{WRAPPER}} .t1_about_thumb' => 'text-align: {{VALUE}};',
				],
			]
		);
	
	
    // Url
    $this->add_control(
      'image',
      [
        'label' => 'Choose Image',
        'type' => \Elementor\Controls_Manager::MEDIA,
        'default' => [
          'url' => plugin_dir_url(__DIR__) . 'assets/images/placeholder.png',
        ]
      ]
    );

    $this->end_controls_section();

    /**
     * Image Style
     */
    $this->start_controls_section(
      'image_style',
      [
        'label' => 'Image',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Width
    $this->add_responsive_control(
			'image_width',
			[
				'type' => \Elementor\Controls_Manager::SLIDER,
				'label' => esc_html__( 'Width', 'plugin-name' ),
        'size_units' => [ 'px', 'em', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
					]
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .eopticore_image' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);

    // Height
    $this->add_responsive_control(
			'image_height',
			[
				'type' => \Elementor\Controls_Manager::SLIDER,
				'label' => esc_html__( 'Height', 'plugin-name' ),
        'size_units' => [ 'px', 'em', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
					]
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .eopticore_image' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		
		$this->add_responsive_control(
			'space',
			[
				'label' => esc_html__( 'Max Width', 'elementor' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'default' => [
					'unit' => '%',
				],
				'tablet_default' => [
					'unit' => '%',
				],
				'mobile_default' => [
					'unit' => '%',
				],
				'size_units' => [ '%', 'px', 'vw' ],
				'range' => [
					'%' => [
						'min' => 1,
						'max' => 100,
					],
					'px' => [
						'min' => 1,
						'max' => 1000,
					],
					'vw' => [
						'min' => 1,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .eopticore_image' => 'max-width: {{SIZE}}{{UNIT}};',
				],
			]
		);
		
		
		// Left
		$this->add_responsive_control(
		'img_Left',
		[
			'label' => esc_html__( 'Img Left', 'elementor' ),
			'type' => \Elementor\Controls_Manager::SLIDER,
			'size_units' => [ 'px', '%' ],
			'range' => [
				'px' => [
					'min' => -100,
					'max' => 500,
				],
				'%' => [
					'min' => -100,
					'max' => 100,
				],		
			],						
			'selectors' => [
				'{{WRAPPER}} .eopticore_image' => 'left: {{SIZE}}{{UNIT}};',
			],
		]
	);
		
	// Top
		$this->add_responsive_control(
		'img_Top',
		[
			'label' => esc_html__( 'Img Top', 'elementor' ),
			'type' => \Elementor\Controls_Manager::SLIDER,
			'size_units' => [ 'px', '%' ],
			'range' => [
				'px' => [
					'min' => -100,
					'max' => 500,
				],
				'%' => [
					'min' => -100,
					'max' => 100,
				],		
			],						
			'selectors' => [
				'{{WRAPPER}} .eopticore_image' => 'top: {{SIZE}}{{UNIT}};',
			],
		]
	);	
	
	 $this->add_responsive_control(
      'img_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .t1_about_thumb ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );
	
	
		
		
    $this->end_controls_section();
  }

  protected function render()
  {
    $settings = $this->get_settings_for_display();

?>

      <div class="t1_about_thumb">
        <img class="eopticore_image" src="<?= esc_url($settings['image']['url']) ?>" alt="">
      </div>

<?php
  }
}
