<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}

/**
 * Counter Widget
 */

class Portfolio_Widget extends \Elementor\Widget_Base {
  public function get_name() {
    return 'opticore-portfolio';
  }

  public function get_title() {
    return esc_html__('opticore Portfolio', 'opticore-widget');
  }

  public function get_categories() {
    return ['basic'];
  }

  /**
   * Controls
   */

  protected function register_controls() {
    // Tab Controls
    $this->start_controls_section(
      'tab_controls',
      [
        'label' => 'Tab Controls',
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

    // Project Style
    $this->add_control(
      'project_style',
      [
        'label' => esc_html__('Project Style', 'textdomain'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => '1',
        'options' => [
          '1'  => esc_html__('One', 'textdomain'),
          '2' => esc_html__('Two', 'textdomain'),
        ],
      ]
    );

    // Tab count
    $this->add_control(
      'tab_count',
      [
        'label' => 'Number of Tabs',
        'type' => \Elementor\Controls_Manager::NUMBER,
        'max' => 12,
        'default' => 3
      ]
    );
	
	/* column_style*/
            $this->add_control(
                'witr_column_grid',
                [
                    'label' => esc_html__( 'Columns style', 'plugin-name' ),
                    'type' => \Elementor\Controls_Manager::SELECT,					
                    'default' => '3',
                    'options' => [
                        '12' => esc_html__( '1', 'plugin-name' ),
                        '6' => esc_html__( '2', 'plugin-name' ),
                        '4' => esc_html__( '3', 'plugin-name' ),
                        '3' => esc_html__( '4', 'plugin-name' ),
                        '2' => esc_html__( '6', 'plugin-name' ),
                    ],
                ]
            );
			
			
			
		// Show show_menu_bar
		$this->add_control(
			'show_menu_bar',
			[
				'label' => esc_html__( 'Show Categori', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'your-plugin' ),
				'label_off' => esc_html__( 'Hide', 'your-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);	
			
			
			
		 // Post count
    $this->add_control(
      'post_count',
      [
        'label' => 'Number of Post',
        'type' => \Elementor\Controls_Manager::NUMBER,
        'max' => 12,
        'default' => 3
      ]
    );	
	
    $this->end_controls_section();



    /** Tab Name Style */

    $this->start_controls_section(
      'tab_style',
      [
        'label' => 'Tab',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    //Tab Color 
    $this->add_control(
      'tab_color',
      [
        'label' => esc_html__('Tab Color', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .item_filter li' => 'color: {{VALUE}}',
        ],
      ]
    );

    //Tab Bg Color 
    $this->add_control(
      'tab_bg_color',
      [
        'label' => esc_html__('Tab Background', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .item_filter li' => 'background-color: {{VALUE}}',
        ],
      ]
    );

    // Tab margin
    $this->add_responsive_control(
      'tab_margin',
      [
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'label' => esc_html__('Margin', 'textdomain'),
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .item_filter li' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

    // Tab padding
    $this->add_responsive_control(
      'tab_padding',
      [
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'label' => esc_html__('Padding', 'textdomain'),
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .item_filter li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

    // Tab Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'tab_typography',
        'selector' => '{{WRAPPER}} .item_filter li',
      ]
    );

    $this->end_controls_section();


    /** Title Style */

    $this->start_controls_section(
      'tilte_style',
      [
        'label' => 'Title',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    /** Title Color */
    $this->add_control(
      'title_color',
      [
        'label' => esc_html__('Title Color', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .project_title a' => 'color: {{VALUE}}',
        ],
      ]
    );

    // Title margin
    $this->add_responsive_control(
      'title_margin',
      [
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'label' => esc_html__('Margin', 'textdomain'),
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .project_title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

    // Title Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'title_typography',
        'selector' => '{{WRAPPER}} .project_title a',
      ]
    );

    $this->end_controls_section();
	
	
	
	  /** Title Style */

    $this->start_controls_section(
      'images_style',
      [
        'label' => 'Images',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );
	
	    // Background
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'background',
        'label' => esc_html__('Background', 'plugin-name'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .txt_img:before',
      ]
    );
  

    $this->end_controls_section();
	
	
	
	
	
	
  }

  protected function render() {
    $settings = $this->get_settings_for_display();

    // Query Posts
    $args = array(
      'post_type' => 'project',
      'post_status' => 'publish',
	  'posts_per_page' => $settings['post_count'],
      'orderby' => 'title',
      'order' => 'ASC',
    );
	

    $loop = new WP_Query($args);

    $tab_slugs = get_categories(array(
      'taxonomy' => 'project_cat',
      'number' => $settings['tab_count'],
      'orderby' => 'name',
      'order'   => 'ASC'
    ));

?>

    <div class="row">
      <div class="col-md-12">
	   <?php if('yes' === $settings['show_menu_bar']): ?>
        <div class="txt_item_filter">
          <ul class="sfilter-menu item_filter ">
            <li class="active_item" data-filter="*">show all</li>

            <?php foreach ($tab_slugs as $tab) : ?>

              <li data-filter=".<?= $tab->slug ?>"><?= $tab->name ?></li>

            <?php endforeach ?>

          </ul>
        </div>
		<?php endif ?>
      </div>
    </div>
    <div class="row txt_portfolio project_filter <?= $settings['project_style'] == '1' ? 'txtstyle_1' : 'txtstyle_2 pr_top' ?> ">

      <?php while ($loop->have_posts()) : $loop->the_post();

        $project_cats = get_the_terms(get_the_ID(), 'project_cat');
        $class = '';
        
        if($project_cats){
          foreach ($project_cats as $cat) {
            $class .= $cat->slug;
            $class .= ' ';
          }
        }

      ?>

        <?php if ($settings['project_style'] == '1') : ?> 

          <!--======== projects ======== -->
          <div class="col-lg-<?= $settings['witr_column_grid'] ?>  grid-item  col-md-6 col-sm-12 <?= $class ?> txt_btm">
            <div class="txt_al_protfolio">
              <div class="txt_img">
                <img src="<?= the_post_thumbnail_url() ?>" alt="">
              </div>
              <div class="txt_icon">
                <a href=""><i class="icofont-ui-search"></i></a>
              </div>
              <div class="txt_content_port">
                <div class="txt_ptitle">
                  <h3 class="project_title"><a href="#"><?= the_title() ?></a></h3>
                  <p class="project_title"><?= the_title() ?></p>
                </div>
              </div>
            </div>
          </div>

        <?php else : ?>

          <div class="col-lg-<?= $settings['witr_column_grid'] ?> grid-item  col-md-6 col-sm-12 <?= $class ?> txt_btm">
            <div class="txt_al_protfolio">
              <div class="txt_img">
                <img src="<?= the_post_thumbnail_url() ?>" alt="">
              </div>
              <div class="tbd_pr_area">
                <div class="txt_content_port">
                  <div class="txt_ptitle">
                    <div class="port_icon">
                      <i class="icofont-network-tower"></i>
                    </div>
                    <h3 class="project_title"><a href="<?= get_the_permalink() ?>"><?= the_title() ?></a></h3>
                    <p><?= the_excerpt() ?></p>
                  </div>
                </div>
              </div>
            </div>
          </div>

        <?php endif ?>

      <?php endwhile ?>

    </div>

   

<?php
  }
}
