<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}

/**
 * Posts Widget
 */

class Posts_Widget extends \Elementor\Widget_Base {
  public function get_name() {
    return 'opticore-posts';
  }

  public function get_title() {
    return esc_html__('opticore Posts', 'opticore-widget');
  }

  public function get_categories() {
    return ['basic'];
  }

  /**
   * Controls
   */

  protected function register_controls() {
    // Content Section
    $this->start_controls_section(
      'content_section',
      [
        'label' => 'Content',
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

	    // Blog Style
    $this->add_control(
      'blog_style',
      [
        'label' => esc_html__('Blog Style', 'textdomain'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => '1',
        'options' => [
          '1'  => esc_html__('One', 'textdomain'),
          '2' => esc_html__('Two', 'textdomain'),
        ],
      ]
    );
	
	
	
	
	
    // Post count
    $this->add_control(
      'post_count',
      [
        'label' => 'Number of Post',
        'type' => \Elementor\Controls_Manager::NUMBER,
        'max' => 12,
        'default' => 3
      ]
    ); 

	
	$this->add_responsive_control(
		'align',
		[
			'label' => esc_html__( 'Alignment', 'elementor' ),
			'type' => \Elementor\Controls_Manager::CHOOSE,
			'options' => [
				'left' => [
					'title' => esc_html__( 'Left', 'elementor' ),
					'icon' => 'eicon-text-align-left',
				],
				'center' => [
					'title' => esc_html__( 'Center', 'elementor' ),
					'icon' => 'eicon-text-align-center',
				],
				'right' => [
					'title' => esc_html__( 'Right', 'elementor' ),
					'icon' => 'eicon-text-align-right',
				],
				'justify' => [
					'title' => esc_html__( 'Justified', 'elementor' ),
					'icon' => 'eicon-text-align-justify',
				],
			],
			'selectors' => [
				'{{WRAPPER}} .txt_blog_body' => 'text-align: {{VALUE}};',
			],
		]
	);
	// Show Icon
    $this->add_control(
			'show_text',
			[
				'label' => esc_html__( 'Show Text', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'your-plugin' ),
				'label_off' => esc_html__( 'Hide', 'your-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);	

		// Show Icon
    $this->add_control(
			'show_icon',
			[
				'label' => esc_html__( 'Show Icon', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'your-plugin' ),
				'label_off' => esc_html__( 'Hide', 'your-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
	
    // Icon
    $this->add_control(
      'service_icon',
      [
        'label' => esc_html__('Icon', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::ICONS,
        'default' => [
          'value' => 'fas fa-circle',
          'library' => 'fa-solid',
        ],
        'recommended' => [
          'fa-solid' => [
            'circle',
            'dot-circle',
            'square-full',
          ],
          'fa-regular' => [
            'circle',
            'dot-circle',
            'square-full',
          ],
        ],
		'condition' => [
				'show_icon' => 'yes',
			],
      ]
    );
	
	
	// Show Icon
    $this->add_control(
			'show_img',
			[
				'label' => esc_html__( 'Show images', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'your-plugin' ),
				'label_off' => esc_html__( 'Hide', 'your-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);	
	
	
	// Image
    $this->add_control(
      'date_image',
      [
        'label' => esc_html__('Choose Image', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::MEDIA,
        'default' => [
          'url' =>plugin_dir_url(__DIR__) . 'assets/images/placeholder.png',
        ],
		'condition' => [
				'show_img' => 'yes',
			],
      ]
    );
	
	
	
	
	// Show Icon
    $this->add_control(
			'show_btn',
			[
				'label' => esc_html__( 'Show Button', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'your-plugin' ),
				'label_off' => esc_html__( 'Hide', 'your-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);	
	
	 /** Button Text */
    $this->add_control(
      'blog_button',
      [
        'label' => 'Button Text',
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => 'Read More',
		'condition' => [
				'show_btn' => 'yes',
			],
      ]
	  
    );

    /** Button Url */
    $this->add_control(
      'button_link',
      [
        'label' => esc_html__('Button Link', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::URL,
        'placeholder' => esc_html__('https://your-link.com', 'plugin-name'),
        'options' => ['url', 'is_external', 'nofollow'],
        'default' => [
          'url' => '',
          'is_external' => true,
          'nofollow' => true,
          // 'custom_attributes' => '',
        ],
        'label_block' => true,
      ],
	  
    );
	
	
	// Post count
    $this->add_control(
      'content_show',
      [
        'label' => 'Content of Post',
        'type' => \Elementor\Controls_Manager::NUMBER,
        'max' => 150,
        'default' => 15
      ]
    );

	
	
	
	
	
    $this->end_controls_section();
	
	
	
	// Content Section
    $this->start_controls_section(
      'slider_section',
      [
        'label' => 'Slick Option',
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );
	
	
	
	
	// Auto Play
    $this->add_control(
      'auto_play',
      [
        'label' => esc_html__('Auto Play', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => 'true',
        'options' => [
          'true'  => esc_html__('True', 'plugin-name'),
          'false' => esc_html__('False', 'plugin-name'),
        ],
      ]
    );

    // Speed
    $this->add_control(
      'speed',
      [
        'label' => esc_html__('Speed', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 100,
        'max' => 10000,
        'default' => 900,
      ]
    );

    // AutoPlay Speed
    $this->add_control(
      'autoplay_speed',
      [
        'label' => esc_html__('Autoplay Speed', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 100,
        'max' => 10000,
        'default' => 900,
      ]
    );


    // Slide To Show
    $this->add_control(
      'slide_to_show',
      [
        'label' => esc_html__('Slide To Show', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 1,
        'max' => 6,
        'default' => 1,
      ]
    ); 

    // Slide To Scroll
    $this->add_control(
      'slide_to_scroll',
      [
        'label' => esc_html__('Slide To Scroll', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 1,
        'max' => 6,
        'default' => 1,
      ]
    );


    // Dot
    $this->add_control(
      'dot',
      [
        'label' => esc_html__('Dot', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => 'false',
        'options' => [
          'true'  => esc_html__('True', 'plugin-name'),
          'false' => esc_html__('False', 'plugin-name'),
        ],
      ]
    );

    
    // Arrows
    $this->add_control(
      'arrows',
      [
        'label' => esc_html__('Arrows', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => 'true',
        'options' => [
          'true'  => esc_html__('True', 'plugin-name'),
          'false' => esc_html__('False', 'plugin-name'),
        ],
      ]
    );

    // Infinite
    $this->add_control(
      'infinite',
      [
        'label' => esc_html__('Infinite', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => 'true',
        'options' => [
          'true'  => esc_html__('True', 'plugin-name'),
          'false' => esc_html__('False', 'plugin-name'),
        ],
      ]
    );

	
	
		// Slide To Show
    $this->add_control(
      'slide_rea_show',
      [
        'label' => esc_html__('Mobel Show', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 1,
        'max' => 6,
        'default' => 2,
      ]
    );
	// Slide To Show
    $this->add_control(
      'slide_reas_show',
      [
        'label' => esc_html__('Tablet Show', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 1,
        'max' => 6,
        'default' => 2,
      ]
    );
	
	// Slide To Show
    $this->add_control(
      'slide_reass_show',
      [
        'label' => esc_html__('Desktop Show', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 1,
        'max' => 6,
        'default' => 2,
      ]
    );
	
	
	
	
    $this->end_controls_section();


	
	
	
	
	 // Box Style
	 $this->start_controls_section(
      'blog_box_style',
      [
        'label' => 'Box Color Option',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );
	// Box Background  
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'blog_background',
        'label' => esc_html__('Background', 'plugin-name'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .txt_blog_body ',
      ]
    ); 
	  // Box Padding 
    $this->add_responsive_control(
      'ser_box_padding',
      [
        'label' => 'Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .txt_blog_body ' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    // Box Margin
    $this->add_responsive_control(
      'ser_box_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .txt_blog_body ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );
	 
	/* box shadow */	
	$this->add_group_control(
		\Elementor\Group_Control_Box_Shadow::get_type(),
		[
			'name' => 'witr_box_shadowsbox',
			'label' => esc_html__( 'Box Shadow', 'opticore' ),
			'selector' => '{{WRAPPER}} .txt_blog_body ',
		]
	); 
	 
	 /* witr_border_style */
	$this->add_control(
		'box_border',
		[
			'label' => esc_html__( 'Border Style', 'plugin-name' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'none' => esc_html__( 'none', 'plugin-name' ),
				'solid' => esc_html__( 'Solid', 'plugin-name' ),
				'double' => esc_html__( 'Double', 'plugin-name' ),
				'dotted' => esc_html__( 'Dotted', 'plugin-name' ),
				'dashed' => esc_html__( 'Dashed', 'plugin-name' ),
				'default' => esc_html__( 'Default', 'plugin-name' ),
			],
			'default' => 'none',
			'selectors' => [
				 '{{WRAPPER}} .txt_blog_body ' => 'border-style: {{VALUE}}',
			],
		]
	);		
	/* witr border */
	
	$this->add_control(
		'box_bods_style',
		[
			'label' => esc_html__( 'Width', 'plugin-name' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'selectors' => [
				 '{{WRAPPER}} .txt_blog_body ' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
			'condition' => [
				'box_border' => ['solid','double','dotted','dashed'],
			],								
		]
	);
	/* border_color */
	$this->add_control(
		'boxs_border1_color',
		[
			'label' => esc_html__( 'Border Color', 'plugin-name' ),
			'type' =>  \Elementor\Controls_Manager::COLOR,
			
			'selectors' => [
				'{{WRAPPER}} .txt_blog_body ' => 'border-color: {{VALUE}}',
			],
			'condition' => [
				'box_border' => ['solid','double','dotted','dashed','default'],
			],								
		]
	);
	/* border_radius */
	$this->add_control(
		'service_border_radius',
		[
			'label' => esc_html__( 'Border Radius', 'plugin-name' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors' => [
				'{{WRAPPER}} .txt_blog_body ' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],							
		]
	);
	 
	 
	 /* border_color */
	$this->add_control(
		'border1_hover_color',
		[
			'label' => esc_html__( 'Border Hover Color', 'plugin-name' ),
			'type' =>  \Elementor\Controls_Manager::COLOR,
			
			'selectors' => [
				'{{WRAPPER}} .txt_blog_body:hover ' => 'border-color: {{VALUE}}',
			],
		]
	);
	
	
	
	
	$this->end_controls_section();
	
	
	
	
	
	
	
    /**
     * Title Style
     */

    $this->start_controls_section(
      'title_style',
      [
        'label' => 'Main Title',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Main Title Color
    $this->add_control(
      'title_color',
      [
        'label' => esc_html__('Color', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .post_widget_title a' => 'color: {{VALUE}} !important',
        ],
      ]
    );

    // Main Title Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'title_typography',
        'selector' => '{{WRAPPER}} .post_widget_title a',
      ]
    );

    // Main Title Padding
    $this->add_responsive_control(
      'title_padding',
      [
        'label' => 'Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .post_widget_title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    // Main Title Margin
    $this->add_responsive_control(
      'title_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .post_widget_title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    $this->end_controls_section();
	
	
	
	
	
	  /**
     * Content Style
     */

    $this->start_controls_section(
      'content_style',
      [
        'label' => 'Content Title',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Content Title Color
    $this->add_control(
      'content_color',
      [
        'label' => esc_html__('Color', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .txt_blog_body p' => 'color: {{VALUE}} !important',
        ],
      ]
    );

    // Content Title Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'content_typography',
        'selector' => '{{WRAPPER}} .txt_blog_body p',
      ]
    );

    // Content Margin
    $this->add_responsive_control(
      'content_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .txt_blog_body p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    $this->end_controls_section();
	
	


    /** Meta */

    $this->start_controls_section(
      'meta_style',
      [
        'label' => 'Meta',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Meta Bg Color
    $this->add_control(
      'meta_bg',
      [
        'label' => esc_html__('Background', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .date_all span' => 'background-color: {{VALUE}} !important',
        ],
      ]
    );

    // Meta Typogrphy
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'meta_typography',
        'selector' => '{{WRAPPER}} .date_all span',
      ]
    );

    $this->end_controls_section();


    /** Exerpt */

    $this->start_controls_section(
      'exerpt_style',
      [
        'label' => 'Exerpt',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );


    // Meta Typogrphy
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'exerpt_typography',
        'selector' => '{{WRAPPER}} .post_widget_exerpt',
      ]
    );

    $this->end_controls_section();
	
	
	
	 
	/**
     * Button Style Section
     */
    $this->start_controls_section(
      'button_style',
      [
        'label' => 'Button Color Option',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    $this->start_controls_tabs(
      'style_tabs'
    );

    // Normal Tab
    $this->start_controls_tab(
      'style_normal_tab',
      [
        'label' => esc_html__('Normal', 'plugin-name'),
      ]
    );

	// Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'button_typography',
        'selector' => '{{WRAPPER}} .stxt_btn .tabtn',
      ]
    );
	
 // Color
    $this->add_control(
      'post_title_color',
      [
        'label' => esc_html__('Title Color', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} a.tabtn' => 'color: {{VALUE}}',
        ],
      ]
    );

    // Background
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'background',
        'label' => esc_html__('Background', 'plugin-name'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} a.tabtn',
      ]
    );

	
	/* border_radius */
	$this->add_control(
		'btn_radius',
		[
			'label' => esc_html__( 'Border Radius', 'plugin-name' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors' => [
				'{{WRAPPER}} a.tabtn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],							
		]
	);
	
    $this->end_controls_tab();

    // Hover Tab
    $this->start_controls_tab(
      'style_hover_tab',
      [
        'label' => esc_html__('Hover', 'plugin-name'),
      ]
    );

    // Color
    $this->add_control(
      'hover_title_color',
      [
        'label' => esc_html__('Title Color', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} a.tabtn:hover' => 'color: {{VALUE}}',
        ],
      ]
    );


    // Background
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'hover_background',
        'label' => esc_html__('Background', 'plugin-name'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} a.tabtn:hover',
      ]
    );
	

	

    $this->end_controls_tab();

    $this->end_controls_tabs();
	
	 $this->end_controls_section();
	
	
	
	
	
	

    // Arrow Dot Style
    $this->start_controls_section(
      'arrow_dot_style',
      [
        'label' => 'Arrow Dot Title',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );
 // Color
    $this->add_control(
      'arre_color',
      [
        'label' => esc_html__('Arrow Color', 'plugin-name'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .slick-slider .next_arrow, {{WRAPPER}} .slick-slider .priv_arrow' => 'color: {{VALUE}}',
        ],
      ]
    );
	
    // Background
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'arrow_background',
        'label' => esc_html__('background', 'plugin-name'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .slick-slider .next_arrow, {{WRAPPER}} .slick-slider .priv_arrow, {{WRAPPER}} .slick-dots li button',
      ]
    );

// Background
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'Active background',
        'label' => esc_html__(' Background', 'plugin-name'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .slick-dots li.slick-active button',
      ]
    );
	
	// Arrow Width
		$this->add_responsive_control(
		  'arrow_font_size',
		  [
			'type' => \Elementor\Controls_Manager::SLIDER,
			'label' => esc_html__('font size', 'plugin-name'),
			'size_units' => ['px'],
			'range' => [
			  'px' => [
				'min' => 0,
				'max' => 500,
			  ],
			  '%' => [
				'min' => 0,
				'max' => 100
			  ]
			],
			'selectors' => [
			  '{{WRAPPER}} .slick-slider .next_arrow, {{WRAPPER}} .slick-slider .priv_arrow, {{WRAPPER}} .slick-dots li button' => 'font-size: {{SIZE}}{{UNIT}};',
			],
		  ]
		);
	
	// Arrow Width
    $this->add_responsive_control(
      'arrow_width',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('Width', 'plugin-name'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
          '{{WRAPPER}} .slick-slider .next_arrow, {{WRAPPER}} .slick-slider .priv_arrow, {{WRAPPER}} .slick-dots li button' => 'width: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
	// Arrow height
    $this->add_responsive_control(
      'arrow_height',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('height', 'plugin-name'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
          '{{WRAPPER}} .slick-slider .next_arrow, {{WRAPPER}} .slick-slider .priv_arrow, {{WRAPPER}} .slick-dots li button' => 'height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );	
	// Arrow height
    $this->add_responsive_control(
      'arrow_line-height',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('line-height', 'plugin-name'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
          '{{WRAPPER}} .slick-slider .next_arrow, {{WRAPPER}} .slick-slider .priv_arrow, {{WRAPPER}} .slick-dots li button' => 'line-height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
	
	/* arrow Opacity */
		$this->add_responsive_control(
			'arrow_opacity',
			[
				'label' => esc_html__( 'Arrow Opacity', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'selectors' => [
					'{{WRAPPER}} .slick-slider .next_arrow, {{WRAPPER}} .slick-slider .priv_arrow, {{WRAPPER}} .slick-dots li button' => 'opacity: {{SIZE}}{{UNIT}};',
				],
			]
		);	
	
	// Arrow Width
    $this->add_responsive_control(
      'active_width',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('Active Width', 'plugin-name'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
          '{{WRAPPER}} .slick-dots li.slick-active button' => 'width: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
	// Arrow Width
    $this->add_responsive_control(
      'active_height',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('Active height', 'plugin-name'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
          '{{WRAPPER}} .slick-dots li.slick-active button' => 'height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
	
	
	
		/* witr_border_style */
			$this->add_control(
				'arrow_border',
				[
					'label' => esc_html__( 'Border Style', 'plugin-name' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'options' => [
						'none' => esc_html__( 'none', 'plugin-name' ),
						'solid' => esc_html__( 'Solid', 'plugin-name' ),
						'double' => esc_html__( 'Double', 'plugin-name' ),
						'dotted' => esc_html__( 'Dotted', 'plugin-name' ),
						'dashed' => esc_html__( 'Dashed', 'plugin-name' ),
						'default' => esc_html__( 'Default', 'plugin-name' ),
					],
					'default' => 'none',
					'selectors' => [
						'{{WRAPPER}} .slick-slider .next_arrow, {{WRAPPER}} .slick-slider .priv_arrow, {{WRAPPER}} .slick-dots li button' => 'border-style: {{VALUE}}',
					],
				]
			);		
			/* witr border */
			
			$this->add_control(
				'arrow_btn_style',
				[
					'label' => esc_html__( 'Width', 'plugin-name' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'selectors' => [
						'{{WRAPPER}} .slick-slider .next_arrow, {{WRAPPER}} .slick-slider .priv_arrow, {{WRAPPER}} .slick-dots li button' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
					'condition' => [
						'arrow_border' => ['solid','double','dotted','dashed'],
					],								
				]
			);
			/* border_color */
			$this->add_control(
				'witr_border1_btn_color',
				[
					'label' => esc_html__( 'Border Color', 'plugin-name' ),
					'type' =>  \Elementor\Controls_Manager::COLOR,
					
					'selectors' => [
						'{{WRAPPER}} .slick-slider .next_arrow, {{WRAPPER}} .slick-slider .priv_arrow, {{WRAPPER}} .slick-dots li button' => 'border-color: {{VALUE}}',
					],
					'condition' => [
						'arrow_border' => ['solid','double','dotted','dashed','default'],
					],								
				]
			);
			/* border_radius */
			$this->add_control(
				'arrow_radius',
				[
					'label' => esc_html__( 'Border Radius', 'plugin-name' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%' ],
					'selectors' => [
						'{{WRAPPER}} .slick-slider .next_arrow, {{WRAPPER}} .slick-slider .priv_arrow, {{WRAPPER}} .slick-dots li button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],								
				]
			);

			/* witr_icon_top */
			$this->add_responsive_control(
				'arrow_top',
				[
					'label' => esc_html__( 'Arrow Top', 'opticore' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => -100,
							'max' => 500,
						],
						'%' => [
							'min' => -100,
							'max' => 100,
						],		
					],						
					'selectors' => [
						'{{WRAPPER}} .slider_active.slick-slider .priv_arrow , {{WRAPPER}} .slider_active.slick-slider .next_arrow, {{WRAPPER}} .slick-dots li button,{{WRAPPER}} .slick-dots' => 'top: {{SIZE}}{{UNIT}};',
					],
				]
			);
			/* witr_icon_top */
			$this->add_responsive_control(
				'arrow_bottom',
				[
					'label' => esc_html__( 'Arrow Bottom', 'opticore' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => -100,
							'max' => 500,
						],
						'%' => [
							'min' => -100,
							'max' => 100,
						],		
					],						
					'selectors' => [
						'{{WRAPPER}} .slider_active.slick-slider .priv_arrow , {{WRAPPER}} .slider_active.slick-slider .next_arrow, {{WRAPPER}} .slick-dots li button,{{WRAPPER}} .slick-dots' => 'bottom: {{SIZE}}{{UNIT}};',
					],
				]
			);
			// Left
			$this->add_responsive_control(
				'arrow_Left',
				[
					'label' => esc_html__( 'Arrow Left', 'opticore' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => -100,
							'max' => 500,
						],
						'%' => [
							'min' => -100,
							'max' => 100,
						],		
					],						
					'selectors' => [
						'{{WRAPPER}} .slider_active.slick-slider .next_arrow,{{WRAPPER}} .slick-dots' => 'left: {{SIZE}}{{UNIT}};',
					],
				]
			);
			// right
			$this->add_responsive_control(
				'arrow_right',
				[
					'label' => esc_html__( 'Arrow right', 'opticore' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => -100,
							'max' => 500,
						],
						'%' => [
							'min' => -100,
							'max' => 100,
						],		
					],						
					'selectors' => [
						'{{WRAPPER}} .slider_active.slick-slider .priv_arrow, {{WRAPPER}} .slick-dots li button ,{{WRAPPER}} .slick-dots ' => 'right: {{SIZE}}{{UNIT}};',
					],
				]
			);
		

	
    
    $this->end_controls_section();
	
	
	
		
	
	
	
	
	
	
	
	
  }

  protected function render() {
    $settings = $this->get_settings_for_display();

    // Query Posts
    $args = array(
      'post_type' => 'post',
      'post_status' => 'publish',
      'posts_per_page' => $settings['post_count'],
      'orderby' => 'title',
      'order' => 'ASC',
    );

    $loop = new WP_Query($args);

?>
  <div class="row">
      <div class="col-lg-12">
  
  <div class="blog_active" id="slick-<?= $this->get_id() ?>" data-slick='{
  "dots": <?= $settings['dot'] ?>,
  "infinite": <?= $settings['infinite'] ?>,
  "autoplay": <?= $settings['auto_play'] ?>,
  "speed": <?= $settings['speed'] ?>,
  "autoplaySpeed": <?= $settings['autoplay_speed'] ?>,
  "slidesToShow": <?= $settings['slide_to_show'] ?>,
  "slidesToScroll": <?= $settings['slide_to_scroll'] ?>,
  "arrows": <?= $settings['arrows'] ?>,
  "prevArrow": "<span class=\"priv_arrow\"><i class=\"icofont-arrow-right\"></i></span>",
  "nextArrow": "<span class=\"next_arrow\"><i class=\"icofont-arrow-left\"></i></span>",
  "responsive": [
    {
      "breakpoint": 1200,
      "settings": {
        "slidesToShow": <?= $settings['slide_reass_show'] ?>,
        "slidesToScroll": 2,
        "infinite": true
      }
    },
    {
      "breakpoint": 992,
      "settings": {
        "slidesToShow": <?= $settings['slide_reas_show'] ?>,
        "slidesToScroll": 2
      }
    },
    {
      "breakpoint": 767,
      "settings": {
        "slidesToShow": <?= $settings['slide_rea_show'] ?>,
        "slidesToScroll": 1
      }
    }
  ]
}'>
  
  
  
  
      <?php while ($loop->have_posts()) : $loop->the_post(); ?>
	  
	  <?php if ($settings['blog_style'] == '1') : ?>
	  
        <!--========  blog_part ======== -->
        <div class="col-lg-12">
          <div class="txt_blog_all_area">
            <div class="txt_blg_image">
              <a href="#"> <img src="<?= the_post_thumbnail_url() ?>" alt=""> </a>
            </div>
            <div class="txt_blog_body">
              <h3 class="post_widget_title"><a href="<?= get_post_permalink() ?>"><?= the_title(); ?></a></h3>
			  <?php if('yes' === $settings['show_text']): ?>
			  
              <p class="post_widget_exerpt"><?php echo wp_trim_words( get_the_excerpt(),  $settings['content_show'], '' ); ?></p>
			 
			  <?php endif ?>
			  
			  <div class="date_all thumb_area">
                <span>
					 <?php if('yes' === $settings['show_img']): ?>
					<img src="<?= esc_url($settings['date_image']['url']) ?>" alt="">
					<?php endif ?>
					Mira 
				</span>
                <span><?= the_modified_date() ?></span>
              </div>
			  
              <div class="stxt_btn">
			  <?php if('yes' === $settings['show_btn']): ?>
				<a <?php echo $this->get_render_attribute_string( 'button_link' ); ?> class="tabtn"><?= $settings['blog_button'] ?></a>
				<?php endif ?>
			  </div>
            </div>
          </div>
        </div>
		
		<?php else : ?>
		
	<?php if ($settings['blog_style'] == '2') : ?>
	<div class="col-lg-12">
		<div class="txt_blog_all_area style_02">
			<div class="txt_blg_image">
				<a href="#"> <img src="<?= the_post_thumbnail_url() ?>" alt=""> </a>
			</div>
			<div class="bl_ic">
				<?php if('yes' === $settings['show_icon']): ?>
				<?php \Elementor\Icons_Manager::render_icon($settings['service_icon'], ['aria-hidden' => 'true', 'class' => 'service_icon']); ?>
				 <?php endif ?>
			</div>
			<div class="txt_blog_body">
				<div class="txt_blog_inner">
					<div class="date_all">
						<span><?= get_the_category()[0]->cat_name ?></span>
						<span><?= the_modified_date() ?></span>
					  <span>- By: Admin,</span>
				   </div>
					<h3 class="post_widget_title"><a href="<?= get_post_permalink() ?>"><?= the_title(); ?></a></h3>
					
					
					
					<p class="post_widget_exerpt"><?= get_the_excerpt() ?></p>
				</div>
				<div class="blog_coment">
					<p>Comments (<?= get_comments_number() ?>)</p>
					<div class="star_i">
					  <i class="icofont-star star_color"></i>
					  <i class="icofont-star star_color"></i>
					  <i class="icofont-star star_color"></i>
					  <i class="icofont-star star_color"></i>
					  <i class="icofont-star "></i>
					  <p>(04)</p>
					</div>
				</div>
			</div>
		</div>
	</div>
		
		
		<?php endif ?>
		<?php endif ?>

      <?php endwhile;
      wp_reset_postdata();
      ?>
	  
    </div>
    </div>
    </div>
	
	
	

	 <?php if (is_admin()) :
      if (!defined('ELEMENTOR_VERSION'))
        return;
    ?>
      <script>
        // $(".slider_active").slick();

        $("#slick-<?= $this->get_id() ?>").slick();

      </script>

    <?php endif ?>
	


<?php
  }
}
