<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}

/**
 * Counter Widget
 */

class Video_Widget extends \Elementor\Widget_Base
{
  public function get_name()
  {
    return 'opticore-video';
  }

  public function get_title()
  {
    return esc_html__('opticore Video', 'opticore-widget');
  }

  public function get_categories()
  {
    return ['basic'];
  }

  /**
   * Controls
   */

  protected function register_controls()
  {
    // Content Section
    $this->start_controls_section(
      'content_section',
      [
        'label' => 'Content',
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

    // Url
    $this->add_control(
			'video_link',
			[
				'label' => esc_html__( 'Video Link', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => esc_html__( 'https://your-link.com', 'plugin-name' ),
				'options' => [ 'url', 'is_external', 'nofollow' ],
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
					// 'custom_attributes' => '',
				],
				'label_block' => true,
			]
		);

    $this->end_controls_section();

    /**
     * Video Style
     */
    $this->start_controls_section(
      'icon_style',
      [
        'label' => 'Icon Style',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'icon_typography',
        'selector' => '{{WRAPPER}} .video_inner i',
      ]
    );

    // Width
    $this->add_responsive_control(
			'icon_width',
			[
				'type' => \Elementor\Controls_Manager::SLIDER,
				'label' => esc_html__( 'Width', 'plugin-name' ),
        'szie_units' => ['px', 'em', '%'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 400,
					],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .video_inner a' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);

    // Height
    $this->add_responsive_control(
			'icon_height',
			[
				'type' => \Elementor\Controls_Manager::SLIDER,
				'label' => esc_html__( 'Height', 'plugin-name' ),
        'szie_units' => ['px', 'em', '%'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 400,
					],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .video_inner a' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);

    // Icon Color
    $this->add_control(
			'icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .video_inner i' => 'color: {{VALUE}}',
				],
			]
		);

    // Icon Background Color
    $this->add_control(
			'icon_bg',
			[
				'label' => esc_html__( 'Icon Background', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .video_inner a, .video_inner a::before' => 'background-color: {{VALUE}}',
				],
			]
		);

    $this->end_controls_section();
  }

  protected function render()
  {
    $settings = $this->get_settings_for_display();

    if ( ! empty( $settings['video_link']['url'] ) ) {
			$this->add_link_attributes( 'video_link', $settings['video_link'] );
		}

?>

    <div class="video_inner">
      <a class=" videobox" data-vbtype="youtube" data-autoplay="true" <?php echo $this->get_render_attribute_string( 'video_link' ); ?>>
        <i class="video_icon fas fa-play"></i></a>
    </div>

<?php
  }
}
