<?php
    /**
     * ReduxFramework Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }


    // This is your option name where all the Redux data is stored.
    $opt_name = "opticore_opt";

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'submenu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => esc_html__( 'Theme Options', 'opticore' ),
        'page_title'           => esc_html__( 'Theme Options', 'opticore' ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => true,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => false,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => false,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => null,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => '',
        // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'red',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */



    /*
     *
     * ---> START SECTIONS
     *
     */

    /*

        As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for


     */

    // -> START Basic Fields
    Redux::setSection( $opt_name, array(
        'title'     => esc_html__('Genarel Option', 'opticore'),
        'id'        => 'wellgoption',
        'icon'      => 'el-icon-cog',
		 'fields'    => array(
				array(
					'id'          => 'dfgfdgdf',
					'type'        => 'info', 
					'title'       => esc_html__('Welcome Our Theme Option', 'opticore'),
				),				
		 )
    ) );

     //Header Logo
    Redux::setSection( $opt_name, array(
        'title'     => ('Header Section'),
        'id'        => 'op_hr',
		'icon'		=> 'el-icon-cog',
		'desc'      =>('heare all heder option'),    
        'fields'    => array( 
		
				array(								
                    'id'        => 'h_bg_color',
                    'type'      => 'background',
                    'title'     => ('Heder Top Section BG'),
                    'default'  => '',
                    'output'    => array('
									.top_bar_area
								'),
					'default' => array(
					 'url' => get_template_directory_uri().'../assets/images/foooter-bg-image.jpg' 
					
					 )	

                ),
				
				
				
				
                array(
					'type'      => 'text',
                    'title'     =>('opening our'),
                    'id'        => 'op_hr',
                    'desc'      =>('set your top text'),
					'default'  => 'Hed: WELLCOME TO BEST CORPORATE Sloution!',
                ),
				 array(
					 'type'      => 'media',
                    'title'     =>('logo upload'),
                    'id'        => 'logo_upload',
                   'desc'      =>('Here upload your logo'),
					'default' => array(
					 'url' => get_template_directory_uri().'/assets/images/logo-1.png'  
					
					 )
                 ),
				 array(
					 'type'      => 'media',
                    'title'     =>('Transperat logo upload'),
                    'id'        => 'logoss_upload',
                   'desc'      =>('Here upload your logo'),
					'default' => array(
					 'url' => get_template_directory_uri().'/assets/images/logo-1.png' 
					
					 )
                 ),
				 array(
					 'type'      => 'media',
                    'title'     =>('Mobile logo upload'),
                    'id'        => 'logos_upload',
                   'desc'      =>('Here upload your logo'),
					'default' => array(
					 'url' => get_template_directory_uri().'/assets/images/logo-1.png' 
					
					 )
                 ),
				 array(
					'type'      => 'text',
                    'title'     =>('Email'),
                    'id'        => 'email_hr',
					'default'  => 'youremail@gmail.com',
                ),
				array(
					'type'      => 'text',
                    'title'     =>('email sub title'),
                    'id'        => 'email_hr_sub',
					'default'  => 'youremail@gmail.com',
                ),
				array(
					'type'      => 'text',
                    'title'     =>('Phone '),
                    'id'        => 'phone_hr',
					'default'  => 'Call Now Us',
                ),
				array(
					'type'      => 'text',
                    'title'     =>('Phone sub titl'),
                    'id'        => 'Phone_hr_sub',
					'default'  => '+88099765767',
                ),
				 
				 array(
					'type'      => 'text',
                    'title'     =>('Button Text'),
                    'id'        => 'hr_btn',
					'default'  => 'Contact Now',
                ),
				array(
					'type'      => 'text',
                    'title'     =>('Button Url'),
                    'id'        => 'btn_url',
					'default'  => '#',
                ),
				 
				array(								
                    'default'  => '',
					'id'        => 'text_color',
                    'type'      => 'color',
                    'title'     =>(' Menu Color'),
					'output'    => array(
					'color' => '
					.menu1 > ul > li > a
					',
					
					)
                ),
				array(								
                    'title'     =>(' Transperat Menu Color'),
					'id'        => 'text2_color',
                    'type'      => 'color',
                    'default'  => '',
					'output'    => array(
					'color' => '
					.scroll-to-fixed-fixed .menu1 > ul > li > a
					',
					
					)
                ),
				array(								
                    'title'     =>(' Menu text size'),
					'id'        => 'text2_size',
                    'type'      => 'typography',
                    'default'  => '',
					'output'    => array(
					'typography' => '
					.menu1 > ul > li > a
					',
					
					)
                ),
				array(								
                    'id'        => 'menu_bg_color',
                    'type'      => 'background',
                    'title'     => ('Menu BG'),
                    'default'  => '',
                    'output'    => array('
									.menu_bg
								'),
					'default'  => array(
						'background-color' => '',
					)					
                ),	
				
            ),
    ) );
	

		 /*  Breadcrumbs area */
			Redux::setSection( $opt_name, array(
			'title'     => esc_html__('Breadcrumbs Option', 'opticore'),
			'id'        => 'breadcrumbs',
			'icon'      => 'el-icon-cog',
			 'fields'    => array(
					array(								
                    'id'        => 'breadcrumbs_bg_color',
                    'type'      => 'background',
                    'title'     => ('breadcrumbs Section BG'),
                    'default'  => '',
                    'output'    => array('
									.txt_breadcumb
								'),
					'default'  => array(
						'background-color' => '',
					)					
                ),
				array(
					'id'             => 'breadcumb_section',
					'type'           => 'spacing',
					'output'         => array('.txt_breadcumb'),
					'mode'           => 'padding',
					'units'          => array('em', 'px'),
					'units_extended' => 'false',
					'title'          => ('Padding Option'),
					'subtitle'       => (' padding'),
					'desc'           => ('padding'),
					'default'            => array(
						'padding-top'     => '', 
						'padding-right'   => '', 
						'padding-bottom'  => '', 
						'padding-left'    => '',
						'units'          => 'px', 
					)
				),
			array(	
                    'id'        => 'brd_text_color',
                    'type'      => 'color',
                    'title'     => ('breadcrumbs Text Color'),
                    'default'  => '',
					'output'    => array(
						'color' => '.breadcumb-content h1'
					)
                ),
		 )
    ) );
		
   
	

 /*  footer widget area */
    Redux::setSection(
	$opt_name, array(
        'title'      =>( 'Footer Section'),
        'id'          => 'opticore_widget_section',
		'icon'		=> 'el-icon-cog',
        'fields'     => array(
				array(
					'id'             => 'widget_section',
					'type'           => 'spacing',
					'output'         => array('.foot_section'),
					'mode'           => 'padding',
					'units'          => array('em', 'px'),
					'units_extended' => 'false',
					'title'          => ('Padding Option'),
					'subtitle'       => (' padding'),
					'desc'           => ('padding'),
				),
				 array(	
                    'id'        => 'widt_text_color',
                    'type'      => 'color',
                    'title'     => ('Widget Title Text Color'),
                    'default'  => '',
					'output'    => array(
						'color' => '.foot_section .txt_foot_title h3'
					)
                ),
                array(								
                    'id'        => 'content_color',
                    'type'      => 'color',
                    'title'     => ('Widget Text Color'),
                    'default'  => '',
					'output'    => array(
						'color' => '
							.menu-footer-menu-container ul li a,
							.widget_archive ul li a,
							.textwidget p,
							.widget  ul li a
							
							
						')
                ),	
                array(								
                    'id'        => 'widget_hover_color',
                    'type'      => 'color',
                    'title'     => ('Widget Text Hover Color'),
                    'default'  => '',
					'output'    => array(
						'color' => '
							.widget  ul li a:hover
						')
                ),		
				array(								
                    'id'        => 'foote_bg_color',
                    'type'      => 'background',
                    'title'     => ('Footer Section BG'),
                    'default'  => '',
                    'output'    => array('
									.foot_section
								'),
					'default' => array(
					 'url' => get_template_directory_uri().'../assets/images/foooter-bg-image.jpg' 
					
					 )						
                ),	
				
				
            )
    ) );	
	
	//footer copyright text
    Redux::setSection( $opt_name, array(
        'title'     => ('Footer Copyright'),
        'id'        => 'opticore_copyright',
        'desc'      => ('Insert your copyright style'),
		'icon'		=> 'el-icon-cog',
        'subsection' => true,
        'fields'    => array(
              
			   array(								
                    'id'        => 'bg_color',
                    'type'      => 'background',
                    'title'     =>('Copyright Section BG Color'),
                    'default'  => '',
                    'output'    => array('
					.foot_bottom_section
					'),
					'default'  => array(
						'background-color' => '',
					)					
                ),						
				
				array(
					'id'             => 'opticore_copyright_section_spacing',
					'type'           => 'spacing',
					'output'         => array('.footer-bottom'),
					'mode'           => 'padding',
					'units'          => array('em', 'px'),
					'units_extended' => 'false',
					'title'          => esc_html__('Padding Option', 'opticore'),
					'default'            => array(
						'padding-top'     => '', 
						'padding-right'   => '', 
						'padding-bottom'  => '', 
						'padding-left'    => '',
						'units'          => 'px', 
					)
				),	
			  
                array(
                    'id'        => 'hr_copyright',
                    'type'      => 'editor',
                    'title'     =>('Copyright '),
                    'default'	=>('Copyright &copy; opticore all rights reserved.'),
                ),
                array(								
                    'id'        => 'copyright1',
                    'type'      => 'color',
                    'title'     => ('Copyright Text Color'),
                    'default'  => '',
					'output'    => array(
					'color' => '.foot_bottom_text p'
					)
                ),
                array(								
                    'id'        => 'text_hover_color',
                    'type'      => 'color',
                    'title'     => ('Copyright Text Hover Color'),
                    'default'  => '',
					'output'    => array(
					'color' => '.foot_bottom_text p:hover'
					)
                ),				
               			

				
				
				
            ),
    ) );

	

	
	
	
	
	
	
			
/* ========================
END opticore FOOTER FIELD
=========================*/	